pub enum DevTmuxCommand {
Start(DevTmuxStartArgs),
Capture(DevTmuxTargetArgs),
Send(DevTmuxSendArgs),
Stop(DevTmuxStopArgs),
}Expand description
Hidden tmux helper subcommands for manual Tau end-to-end sessions.
Variants
Start(DevTmuxStartArgs)
Start Tau in an isolated scratch environment inside tmux.
Capture(DevTmuxTargetArgs)
Capture the current tmux pane contents.
Send(DevTmuxSendArgs)
Send text to the tmux pane, followed by Enter by default.
Stop(DevTmuxStopArgs)
Stop the private tmux server.