pub struct RoleOverrideArgs {
pub enable_role: Vec<String>,
pub disable_role: Vec<String>,
pub disable_roles_all: u8,
}Fields
enable_role: Vec<String>Enable a configured role after all config files are loaded.
disable_role: Vec<String>Disable a configured role after all config files are loaded.
disable_roles_all: u8Disable every configured role before later CLI role overrides.