pub enum CliError {
Show 13 variants
CachePartial,
CacheInvalid,
Io(Error),
Encode(EncodeError),
Harness(HarnessError),
Inspect(InspectError),
DaemonExited(String),
NoRunningDaemon,
Participant(String),
PromptStdin(PromptStdinError),
SessionNotFound(String),
ForegroundOwnershipUnconfirmed {
message: String,
diagnostic: ForegroundRestorationDiagnostic,
},
TerminalOutputFailed(String),
}Expand description
Errors returned by the CLI.
Variants
CachePartial
Offline cache analysis produced useful output with missing evidence.
CacheInvalid
Offline cache invocation or required schema could not be inspected.
Io(Error)
Encode(EncodeError)
Harness(HarnessError)
Inspect(InspectError)
DaemonExited(String)
NoRunningDaemon
Participant(String)
PromptStdin(PromptStdinError)
SessionNotFound(String)
ForegroundOwnershipUnconfirmed
The attachment stopped because terminal foreground ownership is unconfirmed.
Fields

diagnostic: ForegroundRestorationDiagnosticBounded private restoration diagnostic written by persistent UIs.
TerminalOutputFailed(String)
The attachment stopped after its first reported terminal output failure.