pub enum ComponentLogging {
CliStderr,
RunnerManaged,
}Expand description
Describes how a bundled component gets its global tracing subscriber.
Variants
CliStderr
tau-cli installs a stderr subscriber before invoking the component.
RunnerManaged
The component installs its own subscriber, or does not emit tracing logs.